@@ -13,8 +13,8 @@ from dbt.parser.manifest import MacroManifest, Manifest, ManifestLoader
 from dbt.adapters import factory
 
 _SQLALCHEMY_DIALECTS = {
-    "postgres": "postgresql+psycopg2",
     "redshift": "redshift+psycopg2",
+    "sqlserver": "mssql+pyodbc",
 }
 
 
@@ -26,22 +26,27 @@ def _get_alchemy_engine(adapter: BaseAdapter, connection: Connection) -> Any:
 
     sqlalchemy_kwargs = {}
     format_url = lambda url: url
-    if adapter_type == 'trino':
+    if adapter_type == "trino":
         import dbt.adapters.fal_experimental.support.trino as support_trino
+
         return support_trino.create_engine(adapter)
 
-    if adapter_type in ("postgres", "redshift"):
+    if adapter_type == "redshift":
         # If the given adapter supports the DBAPI (PEP 249), we can
         # use its connection directly for the engine.
         sqlalchemy_kwargs["creator"] = lambda *args, **kwargs: connection.handle
         url = _SQLALCHEMY_DIALECTS.get(adapter_type, adapter_type) + "://"
         url = format_url(url)
+    elif adapter_type == "sqlserver":
+        sqlalchemy_kwargs["creator"] = lambda *args, **kwargs: connection.handle
+        url = _SQLALCHEMY_DIALECTS.get(adapter_type, adapter_type) + "://"
+        url = format_url(url)
     else:
         message = (
             f"dbt-fal does not support {adapter_type} adapter. ",
             f"If you need {adapter_type} support, you can create an issue ",
             "in our GitHub repository: https://github.com/fal-ai/fal. ",
-            "We will look into it ASAP."
+            "We will look into it ASAP.",
         )
         raise NotImplementedError(message)
 
@@ -67,21 +72,28 @@ def write_df_to_relation(
     """Generic version of the write_df_to_relation. Materialize the given
     dataframe to the targeted relation on the adapter."""
 
-    if adapter.type() == "snowflake":
+    adapter_type = adapter.type()
+
+    if adapter_type == "snowflake":
         import dbt.adapters.fal_experimental.support.snowflake as support_snowflake
 
         return support_snowflake.write_df_to_relation(adapter, dataframe, relation)
 
-    elif adapter.type() == "bigquery":
+    elif adapter_type == "bigquery":
         import dbt.adapters.fal_experimental.support.bigquery as support_bq
 
         return support_bq.write_df_to_relation(adapter, dataframe, relation)
 
-    elif adapter.type() == "duckdb":
+    elif adapter_type == "duckdb":
         import dbt.adapters.fal_experimental.support.duckdb as support_duckdb
 
         return support_duckdb.write_df_to_relation(adapter, dataframe, relation)
 
+    elif adapter_type == "postgres":
+        import dbt.adapters.fal_experimental.support.postgres as support_postgres
+
+        return support_postgres.write_df_to_relation(adapter, dataframe, relation)
+
     else:
         with new_connection(adapter, "fal:write_df_to_relation") as connection:
             # TODO: this should probably live in the materialization macro.
@@ -112,21 +124,28 @@ def write_df_to_relation(
 def read_relation_as_df(adapter: BaseAdapter, relation: BaseRelation) -> pd.DataFrame:
     """Generic version of the read_df_from_relation."""
 
-    if adapter.type() == "snowflake":
+    adapter_type = adapter.type()
+
+    if adapter_type == "snowflake":
         import dbt.adapters.fal_experimental.support.snowflake as support_snowflake
 
         return support_snowflake.read_relation_as_df(adapter, relation)
 
-    elif adapter.type() == "bigquery":
+    elif adapter_type == "bigquery":
         import dbt.adapters.fal_experimental.support.bigquery as support_bq
 
         return support_bq.read_relation_as_df(adapter, relation)
 
-    elif adapter.type() == "duckdb":
+    elif adapter_type == "duckdb":
         import dbt.adapters.fal_experimental.support.duckdb as support_duckdb
 
         return support_duckdb.read_relation_as_df(adapter, relation)
 
+    elif adapter_type == "postgres":
+        import dbt.adapters.fal_experimental.support.postgres as support_postgres
+
+        return support_postgres.read_relation_as_df(adapter, relation)
+
     else:
         with new_connection(adapter, "fal:read_relation_as_df") as connection:
             alchemy_engine = _get_alchemy_engine(adapter, connection)
@@ -143,15 +162,25 @@ def prepare_for_adapter(adapter: BaseAdapter, function: Any) -> Any:
 
     @functools.wraps(function)
     def wrapped(quoted_relation: str, *args, **kwargs) -> Any:
-        relation = adapter.Relation.create(
-            *quoted_relation.split("."), type=RelationType.Table
+        # HACK: we need to drop the quotes from the relation parts
+        # This was introduced in https://github.com/dbt-labs/dbt-core/pull/7115
+        # and the recommended solution would be to create a macro `fal__resolve_model_name`
+        # but it is not possible thanks a macro resolution error we get by returning the db_adapter type.
+        # The overall solution could be to avoid creating a Relation and just passing the string as is to the read/write functions.
+        parts = map(
+            lambda part: part.strip(adapter.Relation.quote_character),
+            [*quoted_relation.split(".")],
         )
+
+        relation = adapter.Relation.create(*parts, type=RelationType.Table)
         return function(adapter, relation, *args, **kwargs)
 
     return wrapped
 
 
-def reconstruct_adapter(config: RuntimeConfig, manifest: Manifest, macro_manifest: MacroManifest) -> BaseAdapter:
+def reconstruct_adapter(
+    config: RuntimeConfig, manifest: Manifest, macro_manifest: MacroManifest
+) -> BaseAdapter:
     from dbt.tracking import do_not_track
 
     # Prepare the DBT to not to track us.
