@@ -15,6 +15,7 @@ import uuid
 from functools import wraps
 from typing import Any, List, Optional
 import inspect
+from dbt.config.runtime import RuntimeConfig
 
 import platform
 
@@ -110,6 +111,12 @@ def dbt_installed_version():
         return
 
 
+def get_dbt_adapter_type(config: RuntimeConfig) -> str:
+    """Returns: the configured actual DBT adapter"""
+    target = config.to_target_dict()
+    return target["type"]
+
+
 def fal_installed_version():
     """Returns: fal version"""
     try:
@@ -159,16 +166,16 @@ def check_uid():
     conf = read_conf_file(uid_path)  # file already exist due to version check
     if "uid" not in conf.keys():
         uid = str(uuid.uuid4())
-        res = write_conf_file(uid_path, {"uid": uid}, error=True)
-        if res:
-            return "NO_UID", res, True
+        err = write_conf_file(uid_path, {"uid": uid}, error=True)
+        if err:
+            return "NO_UID", err, True
         else:
             return uid, None, True
 
     return conf.get("uid") or "NO_UID", None, False
 
 
-def check_stats_enabled():
+def check_stats_enabled() -> bool:
     """
     Check if the user allows us to use telemetry. In order of precedence:
     1. If FAL_STATS_ENABLED is defined, check its value
@@ -270,6 +277,7 @@ def log_api(
         "total_runtime": str(total_runtime),
         "python_version": python_version(),
         "dbt_version": dbt_installed_version(),
+        "dbt_adapter": get_dbt_adapter_type(config),
         "docker_container": is_docker(),
         "airflow": is_airflow(),
         "github_action": is_github(),
